#!/usr/bin/env python

import csv
import getopt
import sys

def usage(f=sys.stdout):
    f.write("""\
Usage: %s HOST PORT FILENAME.pcap

Extracts simple TCP features from a pcap file and writes them to CSV.
HOST and PORT are the address of the server.
""" % sys.argv[0])

def fmtbool(b):
    if b:
        return "T"
    else:
        return "F"

_, args = getopt.gnu_getopt(sys.argv[1:], "")

try:
    host, port, pcap_filename = args
    port = int(port)
except ValueError:
    usage(sys.stderr)
    sys.exit(1)

# suppress the scapy warning "No route found for IPv6 destination"
# https://stackoverflow.com/a/13249436
import logging
logging.getLogger("scapy.runtime").setLevel(logging.ERROR)
import scapy.all

csvw = csv.DictWriter(sys.stdout, ["host", "port", "ts", "dir", "size", "syn", "psh"])
wrote_header = False

pcap = scapy.all.rdpcap(pcap_filename)
for pkt in pcap:
    ip = pkt[scapy.all.IP]
    tcp = pkt[scapy.all.TCP]
    row = {}
    if ip.dst == host and tcp.dport == port:
        row["dir"] = "up"
    elif ip.src == host and tcp.sport == port:
        row["dir"] = "down"
    else:
        # not related to HOST:PORT
        continue
    row["host"] = host
    row["port"] = port
    row["ts"] = pkt.time
    row["size"] = len(tcp)
    row["syn"] = fmtbool(tcp.flags & 0x02 != 0)
    row["psh"] = fmtbool(tcp.flags & 0x08 != 0)
    if not wrote_header:
        csvw.writeheader()
        wrote_header = True
    csvw.writerow(row)

if not wrote_header:
    print >> sys.stderr, "error: no matches for host %s and port %d" % (host, port)
    sys.exit(1)
