library(ggplot2)

load_trace <- function(filename) {
	x <- read.csv(filename)
	x$ts <- x$ts - min(x$ts)
	x$sz <- x$size * ifelse(x$dir=="up", 1, -1)
	x
}

x <- data.frame()
x <- rbind(x, data.frame(proto="or", load_trace("vanilla.csv")))
x <- rbind(x, data.frame(proto="iat0", load_trace("iat0.csv")))
x <- rbind(x, data.frame(proto="iat1", load_trace("iat1.csv")))
x <- rbind(x, data.frame(proto="iat2", load_trace("iat2.csv")))

head(x)

make_graph <- function(x) {
	p <- ggplot(x, aes(x=ts, y=sz, ymin=0, ymax=sz, color=dir))
	p <- p + geom_linerange(size=0.5, alpha=0.9)
	# p <- p + geom_point(aes(size=psh))
	p <- p + scale_x_continuous(breaks=0:6, minor_breaks=NULL)
	p <- p + scale_y_continuous(breaks=c(-1500, -1000, -500, 0, 500, 1000, 1500), minor_breaks=NULL, labels=function(x){abs(x)})
	p <- p + scale_size_manual(values=c("FALSE"=0, "TRUE"=2))
	p <- p + scale_color_manual(breaks=c("up", "down"), values=c(up="goldenrod", down="darkviolet"), guide=F)
	p <- p + coord_cartesian(xlim=c(0, 6.0), ylim=c(min(x$sz, -1540), max(x$sz, 1540)))
	p <- p + guides(guide_legend(override.aes=list(shape=16, size=5, alpha=1)))
	p <- p + labs(x="time (seconds)", y="segment size")
	p <- p + theme_minimal()
	p <- p + theme(panel.grid=element_line(size=0.1))
	p <- p + theme(axis.text.y=element_text(size=8))
	p
}

p <- make_graph(x[x$proto=="or", ])
ggsave("vanilla.png", p, width=7, height=2.5, dpi=120)

p <- make_graph(x[x$proto=="iat0", ])
ggsave("iat0.png", p, width=7, height=2.5, dpi=120)

p <- make_graph(x[x$proto=="iat1", ])
ggsave("iat1.png", p, width=7, height=2.5, dpi=120)

p <- make_graph(x[x$proto=="iat2", ])
ggsave("iat2.png", p, width=7, height=2.5, dpi=120)
